@@ -1,8 +1,8 @@
 spCdfplot <- function(inp, x, cond = NULL, approx = c(FALSE, TRUE), 
                       n = 10000, bounds = TRUE, ...) {
   ## initializations
-  if ( !class(inp) == "synthPopObj" ) {
-    stop("input argument 'inp' must be of class 'synthPopObj'!\n")
+  if ( !class(inp) == "simPopObj" ) {
+    stop("input argument 'inp' must be of class 'simPopObj'!\n")
   }
   
   weights.pop <- inp@pop@weight
